@@ -15,7 +15,7 @@ Usage::
 import sys
 from typing import Any, Dict, Type
 
-from botocore.client import ClientMeta
+from botocore.client import BaseClient, ClientMeta
 
 from .type_defs import (
     ComprehendMedicalAsyncJobFilterTypeDef,
@@ -73,18 +73,25 @@ class Exceptions:
     ValidationException: Type[BotocoreClientError]
 
 
-class ComprehendMedicalClient:
+class ComprehendMedicalClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/comprehendmedical.html#ComprehendMedical.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/comprehendmedical.html#ComprehendMedical.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html)
     """
 
     meta: ClientMeta
-    exceptions: Exceptions
+
+    @property
+    def exceptions(self) -> Exceptions:
+        """
+        ComprehendMedicalClient exceptions.
+        """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/comprehendmedical.html#ComprehendMedical.Client.can_paginate)
+        Check if an operation can be paginated.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/comprehendmedical.html#ComprehendMedical.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#can_paginate)
         """
 
@@ -92,7 +99,9 @@ class ComprehendMedicalClient:
         self, *, JobId: str
     ) -> DescribeEntitiesDetectionV2JobResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/comprehendmedical.html#ComprehendMedical.Client.describe_entities_detection_v2_job)
+        Gets the properties associated with a medical entities detection job.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/comprehendmedical.html#ComprehendMedical.Client.describe_entities_detection_v2_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#describe_entities_detection_v2_job)
         """
 
@@ -100,13 +109,18 @@ class ComprehendMedicalClient:
         self, *, JobId: str
     ) -> DescribeICD10CMInferenceJobResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/comprehendmedical.html#ComprehendMedical.Client.describe_icd10_cm_inference_job)
+        Gets the properties associated with an InferICD10CM job.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/comprehendmedical.html#ComprehendMedical.Client.describe_icd10_cm_inference_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#describe_icd10_cm_inference_job)
         """
 
     def describe_phi_detection_job(self, *, JobId: str) -> DescribePHIDetectionJobResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/comprehendmedical.html#ComprehendMedical.Client.describe_phi_detection_job)
+        Gets the properties associated with a protected health information (PHI)
+        detection job.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/comprehendmedical.html#ComprehendMedical.Client.describe_phi_detection_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#describe_phi_detection_job)
         """
 
@@ -114,25 +128,36 @@ class ComprehendMedicalClient:
         self, *, JobId: str
     ) -> DescribeRxNormInferenceJobResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/comprehendmedical.html#ComprehendMedical.Client.describe_rx_norm_inference_job)
+        Gets the properties associated with an InferRxNorm job.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/comprehendmedical.html#ComprehendMedical.Client.describe_rx_norm_inference_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#describe_rx_norm_inference_job)
         """
 
     def detect_entities(self, *, Text: str) -> DetectEntitiesResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/comprehendmedical.html#ComprehendMedical.Client.detect_entities)
+        The `DetectEntities` operation is deprecated.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/comprehendmedical.html#ComprehendMedical.Client.detect_entities)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#detect_entities)
         """
 
     def detect_entities_v2(self, *, Text: str) -> DetectEntitiesV2ResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/comprehendmedical.html#ComprehendMedical.Client.detect_entities_v2)
+        Inspects the clinical text for a variety of medical entities and returns
+        specific information about them such as entity category, location, and
+        confidence score on that information.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/comprehendmedical.html#ComprehendMedical.Client.detect_entities_v2)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#detect_entities_v2)
         """
 
     def detect_phi(self, *, Text: str) -> DetectPHIResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/comprehendmedical.html#ComprehendMedical.Client.detect_phi)
+        Inspects the clinical text for protected health information (PHI) entities and
+        returns the entity category, location, and confidence score for each entity.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/comprehendmedical.html#ComprehendMedical.Client.detect_phi)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#detect_phi)
         """
 
@@ -144,67 +169,86 @@ class ComprehendMedicalClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/comprehendmedical.html#ComprehendMedical.Client.generate_presigned_url)
+        Generate a presigned url given a client, its method, and arguments.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/comprehendmedical.html#ComprehendMedical.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#generate_presigned_url)
         """
 
     def infer_icd10_cm(self, *, Text: str) -> InferICD10CMResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/comprehendmedical.html#ComprehendMedical.Client.infer_icd10_cm)
+        InferICD10CM detects medical conditions as entities listed in a patient record
+        and links those entities to normalized concept identifiers in the ICD-10-CM
+        knowledge base from the Centers for Disease Control.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/comprehendmedical.html#ComprehendMedical.Client.infer_icd10_cm)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#infer_icd10_cm)
         """
 
     def infer_rx_norm(self, *, Text: str) -> InferRxNormResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/comprehendmedical.html#ComprehendMedical.Client.infer_rx_norm)
+        InferRxNorm detects medications as entities listed in a patient record and links
+        to the normalized concept identifiers in the RxNorm database from the National
+        Library of Medicine.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/comprehendmedical.html#ComprehendMedical.Client.infer_rx_norm)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#infer_rx_norm)
         """
 
     def list_entities_detection_v2_jobs(
         self,
         *,
-        Filter: ComprehendMedicalAsyncJobFilterTypeDef = None,
+        Filter: "ComprehendMedicalAsyncJobFilterTypeDef" = None,
         NextToken: str = None,
         MaxResults: int = None
     ) -> ListEntitiesDetectionV2JobsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/comprehendmedical.html#ComprehendMedical.Client.list_entities_detection_v2_jobs)
+        Gets a list of medical entity detection jobs that you have submitted.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/comprehendmedical.html#ComprehendMedical.Client.list_entities_detection_v2_jobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#list_entities_detection_v2_jobs)
         """
 
     def list_icd10_cm_inference_jobs(
         self,
         *,
-        Filter: ComprehendMedicalAsyncJobFilterTypeDef = None,
+        Filter: "ComprehendMedicalAsyncJobFilterTypeDef" = None,
         NextToken: str = None,
         MaxResults: int = None
     ) -> ListICD10CMInferenceJobsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/comprehendmedical.html#ComprehendMedical.Client.list_icd10_cm_inference_jobs)
+        Gets a list of InferICD10CM jobs that you have submitted.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/comprehendmedical.html#ComprehendMedical.Client.list_icd10_cm_inference_jobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#list_icd10_cm_inference_jobs)
         """
 
     def list_phi_detection_jobs(
         self,
         *,
-        Filter: ComprehendMedicalAsyncJobFilterTypeDef = None,
+        Filter: "ComprehendMedicalAsyncJobFilterTypeDef" = None,
         NextToken: str = None,
         MaxResults: int = None
     ) -> ListPHIDetectionJobsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/comprehendmedical.html#ComprehendMedical.Client.list_phi_detection_jobs)
+        Gets a list of protected health information (PHI) detection jobs that you have
+        submitted.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/comprehendmedical.html#ComprehendMedical.Client.list_phi_detection_jobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#list_phi_detection_jobs)
         """
 
     def list_rx_norm_inference_jobs(
         self,
         *,
-        Filter: ComprehendMedicalAsyncJobFilterTypeDef = None,
+        Filter: "ComprehendMedicalAsyncJobFilterTypeDef" = None,
         NextToken: str = None,
         MaxResults: int = None
     ) -> ListRxNormInferenceJobsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/comprehendmedical.html#ComprehendMedical.Client.list_rx_norm_inference_jobs)
+        Gets a list of InferRxNorm jobs that you have submitted.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/comprehendmedical.html#ComprehendMedical.Client.list_rx_norm_inference_jobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#list_rx_norm_inference_jobs)
         """
 
@@ -220,7 +264,10 @@ class ComprehendMedicalClient:
         KMSKey: str = None
     ) -> StartEntitiesDetectionV2JobResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/comprehendmedical.html#ComprehendMedical.Client.start_entities_detection_v2_job)
+        Starts an asynchronous medical entity detection job for a collection of
+        documents.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/comprehendmedical.html#ComprehendMedical.Client.start_entities_detection_v2_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#start_entities_detection_v2_job)
         """
 
@@ -236,7 +283,10 @@ class ComprehendMedicalClient:
         KMSKey: str = None
     ) -> StartICD10CMInferenceJobResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/comprehendmedical.html#ComprehendMedical.Client.start_icd10_cm_inference_job)
+        Starts an asynchronous job to detect medical conditions and link them to the
+        ICD-10-CM ontology.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/comprehendmedical.html#ComprehendMedical.Client.start_icd10_cm_inference_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#start_icd10_cm_inference_job)
         """
 
@@ -252,7 +302,9 @@ class ComprehendMedicalClient:
         KMSKey: str = None
     ) -> StartPHIDetectionJobResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/comprehendmedical.html#ComprehendMedical.Client.start_phi_detection_job)
+        Starts an asynchronous job to detect protected health information (PHI).
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/comprehendmedical.html#ComprehendMedical.Client.start_phi_detection_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#start_phi_detection_job)
         """
 
@@ -268,7 +320,10 @@ class ComprehendMedicalClient:
         KMSKey: str = None
     ) -> StartRxNormInferenceJobResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/comprehendmedical.html#ComprehendMedical.Client.start_rx_norm_inference_job)
+        Starts an asynchronous job to detect medication entities and link them to the
+        RxNorm ontology.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/comprehendmedical.html#ComprehendMedical.Client.start_rx_norm_inference_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#start_rx_norm_inference_job)
         """
 
@@ -276,24 +331,32 @@ class ComprehendMedicalClient:
         self, *, JobId: str
     ) -> StopEntitiesDetectionV2JobResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/comprehendmedical.html#ComprehendMedical.Client.stop_entities_detection_v2_job)
+        Stops a medical entities detection job in progress.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/comprehendmedical.html#ComprehendMedical.Client.stop_entities_detection_v2_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#stop_entities_detection_v2_job)
         """
 
     def stop_icd10_cm_inference_job(self, *, JobId: str) -> StopICD10CMInferenceJobResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/comprehendmedical.html#ComprehendMedical.Client.stop_icd10_cm_inference_job)
+        Stops an InferICD10CM inference job in progress.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/comprehendmedical.html#ComprehendMedical.Client.stop_icd10_cm_inference_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#stop_icd10_cm_inference_job)
         """
 
     def stop_phi_detection_job(self, *, JobId: str) -> StopPHIDetectionJobResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/comprehendmedical.html#ComprehendMedical.Client.stop_phi_detection_job)
+        Stops a protected health information (PHI) detection job in progress.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/comprehendmedical.html#ComprehendMedical.Client.stop_phi_detection_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#stop_phi_detection_job)
         """
 
     def stop_rx_norm_inference_job(self, *, JobId: str) -> StopRxNormInferenceJobResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/comprehendmedical.html#ComprehendMedical.Client.stop_rx_norm_inference_job)
+        Stops an InferRxNorm inference job in progress.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/comprehendmedical.html#ComprehendMedical.Client.stop_rx_norm_inference_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/client.html#stop_rx_norm_inference_job)
         """
